@@ -8,21 +8,30 @@ from optimade.models import (
     StructureResponseMany,
     StructureResponseOne,
 )
+from optimade.server.config import CONFIG
+from optimade.server.entry_collections.mongo import MongoCollection, client
+from optimade.server.mappers.structures import (
+    StructureMapper as OptimadeStructureMapper,
+)
 from optimade.server.query_params import EntryListingQueryParams, SingleEntryQueryParams
 
 from aiida_optimade.entry_collections import AiidaCollection
 from aiida_optimade.mappers import StructureMapper
 from aiida_optimade.models import StructureResource
-
-from .utils import get_entries, get_single_entry, close_session
+from aiida_optimade.routers.utils import get_entries, get_single_entry, close_session
 
 
 ROUTER = APIRouter(redirect_slashes=True)
 
 STRUCTURES = AiidaCollection(
-    ["data.cif.CifData.", "data.structure.StructureData."],
-    StructureResource,
-    StructureMapper,
+    entities=["data.cif.CifData.", "data.structure.StructureData."],
+    resource_cls=StructureResource,
+    resource_mapper=StructureMapper,
+)
+STRUCTURES_MONGO = MongoCollection(
+    collection=client[CONFIG.mongo_database][CONFIG.structures_collection],
+    resource_cls=StructureResource,
+    resource_mapper=OptimadeStructureMapper,
 )
 
 
@@ -36,7 +45,7 @@ STRUCTURES = AiidaCollection(
 @close_session
 def get_structures(request: Request, params: EntryListingQueryParams = Depends()):
     return get_entries(
-        collection=STRUCTURES,
+        collection=STRUCTURES_MONGO if CONFIG.use_real_mongo else STRUCTURES,
         response=StructureResponseMany,
         request=request,
         params=params,
@@ -55,7 +64,7 @@ def get_single_structure(
     request: Request, entry_id: int, params: SingleEntryQueryParams = Depends()
 ):
     return get_single_entry(
-        collection=STRUCTURES,
+        collection=STRUCTURES_MONGO if CONFIG.use_real_mongo else STRUCTURES,
         entry_id=entry_id,
         response=StructureResponseOne,
         request=request,
